@@ -2,7 +2,7 @@ package Dist::Zilla::PluginBundle::Author::GSG;
 
 # ABSTRACT: Grant Street Group CPAN dists
 use version;
-our $VERSION = 'v0.1.5'; # VERSION
+our $VERSION = 'v0.2.0'; # VERSION
 
 use Carp;
 use Git::Wrapper;
@@ -21,6 +21,7 @@ sub mvp_multivalue_args { qw(
     test_compile_module_finder
     test_compile_script_finder
     test_compile_switch
+    dont_munge
 ) }
 
 sub configure {
@@ -46,11 +47,19 @@ sub configure {
 
     $mm->[2]->{eumm_version} = '7.1101';
 
+    my $name = $self->name;
+
     $self->add_plugins(
         'Author::GSG',
 
+        [ 'FileFinder::Filter' => 'MungeableFiles' => {
+            finder => [ ':InstallModules', ':PerlExecFiles' ],
+            %{ $self->config_slice({ dont_munge => 'skip' }) }
+        }],
+
         'MetaJSON',
         [ 'OurPkgVersion' => {
+            finder           => [ "$name/MungeableFiles" ],
             semantic_version => 1,
         } ],
         'Prereqs::FromCPANfile',
@@ -65,6 +74,7 @@ sub configure {
         [ 'ExecDir' => { dir => 'script' } ],
 
         [ 'PodWeaver' => {
+            finder             => [ "$name/MungeableFiles" ],
             replacer           => 'replace_with_comment',
             post_code_replacer => 'replace_with_nothing',
             config_plugin      => [ '@Default', 'Contributors' ]
@@ -78,7 +88,7 @@ sub configure {
             copy_to_root => 0,
         } ],
 
-        [ 'GSG::Git::NextVersion' => {
+        [ 'Author::GSG::Git::NextVersion' => {
             first_version  => 'v0.0.1',
             version_regexp => '\b(v\d+\.\d+\.\d+)\b',
         } ],
@@ -235,7 +245,7 @@ sub _get_credentials {
 __PACKAGE__->meta->make_immutable;
 
 package # hide from the CPAN
-    Dist::Zilla::Plugin::GSG::Git::NextVersion;
+    Dist::Zilla::Plugin::Author::GSG::Git::NextVersion;
 use Moose;
 BEGIN { extends 'Dist::Zilla::Plugin::Git::NextVersion' }
 
@@ -253,6 +263,7 @@ before 'provide_version' => sub {
 };
 
 __PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -267,7 +278,7 @@ Dist::Zilla::PluginBundle::Author::GSG - Grant Street Group CPAN dists
 
 =head1 VERSION
 
-version v0.1.5
+version v0.2.0
 
 =head1 SYNOPSIS
 
@@ -306,8 +317,14 @@ Some of which comes from L<Dist::Zilla::Plugin::Author::GSG>.
     ; The defaults for author and license come from
     [Author::GSG]
 
+    [ FileFinder::Filter / MungeableFiles ]
+    finder => :InstallModules
+    finder => :PerlExecFiles
+    ; dont_munge = (?^:bin) # can be used multiple times. passed in as "skip"
+
     [MetaJSON]
     [OurPkgVersion]
+    finder = :MungableFiles
     [Prereqs::FromCPANfile]
     [$meta_provides] # defaults to MetaProvides::Package
 
@@ -319,6 +336,7 @@ Some of which comes from L<Dist::Zilla::Plugin::Author::GSG>.
     dir = script    # in addition to bin/ for StaticInstall compatibility
 
     [PodWeaver]
+    finder     = :MungeableFiles
     replacer = replace_with_comment
     post_code_replacer = replace_with_nothing
     config_plugin = [ @Default, Contributors ]
@@ -454,6 +472,18 @@ Passed to L<Dist::Zilla::Plugin::Git::GatherDir/exclude_match>.
 All options for L<Dist::Zilla::Plugin::Test::Compile> should be supported
 with the C<test_compile_> prefix.
 
+=item dont_munge
+
+    [@Author::GSG]
+    dont_munge = (?^:one-off)
+    dont_munge = (?^:docs/.*.txt)
+
+Passed to L<Dist::Zilla::Plugin::FileFinder::Filter> as c<skip> for the
+C<MungableFiles> plugin.
+
+This plugin gets passed to L<Dist::Zilla::Plugin::OurPkgVersion> and
+L<Dist::Zilla::Plugin::PodWeaver> as C<finder> to filter matches.
+
 =back
 
 =head1 Setting up a new dist
